@@ -7,6 +7,7 @@ CREATE FUNCTION @extschema@.partition_data_id(
     , p_analyze boolean DEFAULT true
     , p_source_table text DEFAULT NULL
     , p_ignored_columns text[] DEFAULT NULL
+    , p_override_system_value boolean DEFAULT false
 )
     RETURNS bigint
     LANGUAGE plpgsql
@@ -14,7 +15,8 @@ CREATE FUNCTION @extschema@.partition_data_id(
 DECLARE
 
 v_analyze                   boolean := FALSE;
-v_column_list               text;
+v_column_list_filtered      text;
+v_column_list_full          text;
 v_control                   text;
 v_control_type              text;
 v_current_partition_name    text;
@@ -26,7 +28,8 @@ v_lock_iter                 int := 1;
 v_lock_obtained             boolean := FALSE;
 v_max_partition_id          bigint;
 v_min_partition_id          bigint;
-v_parent_schema             text;
+v_override_statement        text;
+v_parent_schemaname             text;
 v_parent_tablename          text;
 v_partition_interval        bigint;
 v_partition_id              bigint[];
@@ -60,7 +63,7 @@ WHERE schemaname = split_part(p_parent_table, '.', 1)::name
 AND tablename = split_part(p_parent_table, '.', 2)::name;
 
 -- Preserve given parent tablename for use below
-v_parent_schema    := v_source_schemaname;
+v_parent_schemaname    := v_source_schemaname;
 v_parent_tablename := v_source_tablename;
 
 SELECT general_type INTO v_control_type FROM @extschema@.check_control_type(v_source_schemaname, v_source_tablename, v_control);
@@ -106,7 +109,7 @@ ELSE
         v_source_tablename := v_default_tablename;
 
         v_default_exists := true;
-        EXECUTE format ('CREATE TEMP TABLE IF NOT EXISTS partman_temp_data_storage (LIKE %I.%I INCLUDING INDEXES) ON COMMIT DROP', v_source_schemaname, v_source_tablename);
+        EXECUTE format ('CREATE TEMP TABLE IF NOT EXISTS partman_temp_data_storage (LIKE %I.%I INCLUDING DEFAULTS INCLUDING INDEXES) ON COMMIT DROP', v_source_schemaname, v_source_tablename);
     ELSE
         RAISE DEBUG 'No default table found when partition_data_id() was called';
         RETURN v_total_rows;
@@ -118,9 +121,9 @@ IF p_batch_interval IS NULL OR p_batch_interval > v_partition_interval THEN
     p_batch_interval := v_partition_interval;
 END IF;
 
--- Generate column list to use in SELECT/INSERT statements below. Allows for exclusion of GENERATED (or any other desired) columns.
+-- Generate filtered column list to use in SELECT/INSERT statements below. Allows for exclusion of GENERATED (or any other desired) columns.
 SELECT string_agg(quote_ident(attname), ',')
-INTO v_column_list
+INTO v_column_list_filtered
 FROM pg_catalog.pg_attribute a
 JOIN pg_catalog.pg_class c ON a.attrelid = c.oid
 JOIN pg_catalog.pg_namespace n ON c.relnamespace = n.oid
@@ -130,6 +133,17 @@ AND a.attnum > 0
 AND a.attisdropped = false
 AND attname <> ALL(COALESCE(p_ignored_columns, ARRAY[]::text[]));
 
+-- Generate full column list to use in SELECT/INSERT statements below when temp table is in use
+SELECT string_agg(quote_ident(attname), ',')
+INTO v_column_list_full
+FROM pg_catalog.pg_attribute a
+JOIN pg_catalog.pg_class c ON a.attrelid = c.oid
+JOIN pg_catalog.pg_namespace n ON c.relnamespace = n.oid
+WHERE n.nspname = v_source_schemaname
+AND c.relname = v_source_tablename
+AND a.attnum > 0
+AND a.attisdropped = false;
+
 FOR i IN 1..p_batch_count LOOP
 
     IF p_order = 'ASC' THEN
@@ -169,8 +183,7 @@ FOR i IN 1..p_batch_count LOOP
         WHILE v_lock_iter <= 5 LOOP
             v_lock_iter := v_lock_iter + 1;
             BEGIN
-                v_sql := format('SELECT %s FROM ONLY %I.%I WHERE %I >= %s AND %I < %s FOR UPDATE NOWAIT'
-                    , v_column_list
+                v_sql := format('SELECT * FROM ONLY %I.%I WHERE %I >= %s AND %I < %s FOR UPDATE NOWAIT'
                     , v_source_schemaname
                     , v_source_tablename
                     , v_control
@@ -185,73 +198,84 @@ FOR i IN 1..p_batch_count LOOP
                     CONTINUE;
             END;
             EXIT WHEN v_lock_obtained;
-    END LOOP;
-    IF NOT v_lock_obtained THEN
-        RETURN -1;
+        END LOOP;
+        IF NOT v_lock_obtained THEN
+            RETURN -1;
+        END IF;
     END IF;
-END IF;
 
-v_current_partition_name := @extschema@.check_name_length(COALESCE(v_parent_tablename), v_min_partition_id::text, TRUE);
+    v_current_partition_name := @extschema@.check_name_length(COALESCE(v_parent_tablename), v_min_partition_id::text, TRUE);
 
-IF v_default_exists THEN
+    IF p_override_system_value THEN
+        v_override_statement = ' OVERRIDING SYSTEM VALUE ';
+    ELSE
+        v_override_statement = ' ';
+    END IF;
 
-    -- Child tables cannot be created if data that belongs to it exists in the default
-    -- Have to move data out to temporary location, create child table, then move it back
+    IF v_default_exists THEN
 
-    -- Temp table created above to avoid excessive temp creation in loop
-    EXECUTE format('WITH partition_data AS (
-            DELETE FROM %1$I.%2$I WHERE %3$I >= %4$s AND %3$I < %5$s RETURNING *)
-        INSERT INTO partman_temp_data_storage (%6$s) SELECT %6$s FROM partition_data'
-        , v_source_schemaname
-        , v_source_tablename
-        , v_control
-        , v_min_partition_id
-        , v_max_partition_id
-        , v_column_list);
+        -- Child tables cannot be created if data that belongs to it exists in the default
+        -- Have to move data out to temporary location, create child table, then move it back
 
-    -- Set analyze to true if a table is created
-    v_analyze := @extschema@.create_partition_id(p_parent_table, v_partition_id);
+        -- Temp table created above to avoid excessive temp creation in loop
+        -- Must use full column list here since the temp table cannot have generated/identity values for defaults.
+        --      This allows for all scenarios where some people may want newly generated values and others may not.
+        --      Those that want them are handled by the filtered column list when moving to the real table
+        EXECUTE format('WITH partition_data AS (
+                DELETE FROM %1$I.%2$I WHERE %3$I >= %4$s AND %3$I < %5$s RETURNING *)
+            INSERT INTO partman_temp_data_storage (%6$s) SELECT %6$s FROM partition_data'
+            , v_source_schemaname
+            , v_source_tablename
+            , v_control
+            , v_min_partition_id
+            , v_max_partition_id
+            , v_column_list_full);
 
-    EXECUTE format('WITH partition_data AS (
-            DELETE FROM partman_temp_data_storage RETURNING *)
-        INSERT INTO %1$I.%2$I (%3$s) SELECT %3$s FROM partition_data'
-        , v_parent_schema
-        , v_current_partition_name
-        , v_column_list);
+        -- Set analyze to true if a table is created
+        v_analyze := @extschema@.create_partition_id(p_parent_table, v_partition_id);
 
-ELSE
+        EXECUTE format('WITH partition_data AS (
+                DELETE FROM partman_temp_data_storage RETURNING *)
+            INSERT INTO %1$I.%2$I (%3$s) %4$s SELECT %3$s FROM partition_data'
+            , v_parent_schemaname
+            , v_current_partition_name
+            , v_column_list_filtered
+            , v_override_statement);
 
-    -- Set analyze to true if a table is created
-    v_analyze := @extschema@.create_partition_id(p_parent_table, v_partition_id);
+    ELSE
 
-    EXECUTE format('WITH partition_data AS (
-            DELETE FROM ONLY %1$I.%2$I WHERE %3$I >= %4$s AND %3$I < %5$s RETURNING *)
-        INSERT INTO %6$I.%7$I (%8$s) SELECT %8$s FROM partition_data'
-        , v_source_schemaname
-        , v_source_tablename
-        , v_control
-        , v_min_partition_id
-        , v_max_partition_id
-        , v_parent_schema
-        , v_current_partition_name
-        , v_column_list);
+        -- Set analyze to true if a table is created
+        v_analyze := @extschema@.create_partition_id(p_parent_table, v_partition_id);
 
-END IF;
+        EXECUTE format('WITH partition_data AS (
+                DELETE FROM ONLY %1$I.%2$I WHERE %3$I >= %4$s AND %3$I < %5$s RETURNING *)
+            INSERT INTO %6$I.%7$I (%8$s) %9$s SELECT %8$s FROM partition_data'
+            , v_source_schemaname
+            , v_source_tablename
+            , v_control
+            , v_min_partition_id
+            , v_max_partition_id
+            , v_parent_schemaname
+            , v_current_partition_name
+            , v_column_list_filtered
+            , v_override_statement);
 
-GET DIAGNOSTICS v_rowcount = ROW_COUNT;
-v_total_rows := v_total_rows + v_rowcount;
-IF v_rowcount = 0 THEN
-    EXIT;
-END IF;
+    END IF;
+
+    GET DIAGNOSTICS v_rowcount = ROW_COUNT;
+    v_total_rows := v_total_rows + v_rowcount;
+    IF v_rowcount = 0 THEN
+        EXIT;
+    END IF;
 
 END LOOP;
 
 -- v_analyze is a local check if a new table is made.
 -- p_analyze is a parameter to say whether to run the analyze at all. Used by create_parent() to avoid long exclusive lock or run_maintenence() to avoid long creation runs.
 IF v_analyze AND p_analyze THEN
-    RAISE DEBUG 'partiton_data_time: Begin analyze of %.%', v_parent_schema, v_parent_tablename;
-    EXECUTE format('ANALYZE %I.%I', v_parent_schema, v_parent_tablename);
-    RAISE DEBUG 'partiton_data_time: End analyze of %.%', v_parent_schema, v_parent_tablename;
+    RAISE DEBUG 'partiton_data_time: Begin analyze of %.%', v_parent_schemaname, v_parent_tablename;
+    EXECUTE format('ANALYZE %I.%I', v_parent_schemaname, v_parent_tablename);
+    RAISE DEBUG 'partiton_data_time: End analyze of %.%', v_parent_schemaname, v_parent_tablename;
 END IF;
 
 RETURN v_total_rows;
