@@ -11,7 +11,7 @@
 BEGIN;
 SELECT set_config('search_path','partman, public',false);
 
-SELECT plan(221);
+SELECT plan(224);
 
 CREATE SCHEMA partman_test;
 CREATE SCHEMA partman_retention_test;
@@ -147,7 +147,7 @@ SELECT table_privs_are('partman_test', 'time_taptest_table_p'||to_char(CURRENT_T
     'Check partman_revoke privileges of time_taptest_table_p'||to_char(CURRENT_TIMESTAMP-'4 days'::interval, 'YYYYMMDD'));
 
 
-SELECT is_empty('SELECT * FROM ONLY partman_test.time_taptest_table', 'Check that parent table is empty. Should be impossible for native, but leaving test here just cause.');
+SELECT is_empty('SELECT * FROM ONLY partman_test.time_taptest_table_default', 'Check that default table is empty.');
 SELECT results_eq('SELECT count(*)::int FROM partman_test.time_taptest_table', ARRAY[10], 'Check count from parent table');
 SELECT results_eq('SELECT count(*)::int FROM partman_test.time_taptest_table_p'||to_char(CURRENT_TIMESTAMP, 'YYYYMMDD'),
     ARRAY[10], 'Check count from time_taptest_table_p'||to_char(CURRENT_TIMESTAMP, 'YYYYMMDD'));
@@ -590,6 +590,16 @@ SELECT hasnt_table('partman_test', 'time_taptest_table_p'||to_char(CURRENT_TIMES
 INSERT INTO partman_test.time_taptest_table (col1, col3) VALUES (generate_series(200,210), partman.uuid7_time_encoder(CURRENT_TIMESTAMP + '20 days'::interval));
 SELECT results_eq('SELECT count(*)::int FROM ONLY partman_test.time_taptest_table_default', ARRAY[11], 'Check that data child scope goes to default');
 
+-- Test partitioning function works to move data out of default
+SELECT partman.partition_data_time('partman_test.time_taptest_table', 20);
+
+SELECT has_table('partman_test', 'time_taptest_table_p'||to_char(CURRENT_TIMESTAMP+'20 days'::interval, 'YYYYMMDD'),
+    'Check time_taptest_table_p'||to_char(CURRENT_TIMESTAMP+'20 days'::interval, 'YYYYMMDD')||' does exist');
+SELECT is_empty('SELECT * FROM ONLY partman_test.time_taptest_table_default', 'Check that default table is empty after partitioning.');
+SELECT results_eq('SELECT count(*)::int FROM ONLY partman_test.time_taptest_table_p'||to_char(CURRENT_TIMESTAMP+'20 days'::interval, 'YYYYMMDD'), ARRAY[11], 'Check that data went to proper child table after partitioning');
+
+
+-- Test undoing stuff
 SELECT drop_partition_time('partman_test.time_taptest_table', '3 days'::interval, p_keep_table := false);
 SELECT hasnt_table('partman_test', 'time_taptest_table_p'||to_char(CURRENT_TIMESTAMP-'4 days'::interval, 'YYYYMMDD'),
     'Check time_taptest_table_p'||to_char(CURRENT_TIMESTAMP-'4 days'::interval, 'YYYYMMDD')||' does not exist');
@@ -638,4 +648,3 @@ SELECT hasnt_table('partman', 'template_partman_test_time_taptest_table', 'Check
 
 SELECT * FROM finish();
 ROLLBACK;
-
